@@ -20,20 +20,20 @@
 
 #include "wordlist.h"
 
-#include <QtCore/QRegExp>
-#include <QtCore/QDir>
-#include <QtCore/QTextStream>
-#include <QtXml/QXmlParseException>
-#include <QtXml/QXmlAttributes>
-#include <QtXml/QXmlInputSource>
-#include <QtXml/QXmlSimpleReader>
-#include <QProgressDialog>
 #include <QApplication>
+#include <QDir>
+#include <QList>
+#include <QProgressDialog>
+#include <QRegExp>
+#include <QStandardPaths>
 #include <QTextCodec>
+#include <QTextStream>
+#include <QXmlAttributes>
+#include <QXmlInputSource>
+#include <QXmlParseException>
+#include <QXmlSimpleReader>
 
-#include <kstandarddirs.h>
-#include <klocale.h>
-#include <kapplication.h>
+#include <KLocalizedString>
 
 namespace WordList
 {
@@ -155,11 +155,11 @@ bool saveWordList(WordMap map, QString filename)
 
 void addWords(WordMap &map, QString line)
 {
-    const QStringList words = line.split(QRegExp(QLatin1String("\\W")));
+    const QStringList words = line.split(QRegExp(QStringLiteral("\\W")));
 
     QStringList::ConstIterator it;
     for (it = words.constBegin(); it != words.constEnd(); ++it) {
-        if (!(*it).contains(QRegExp(QLatin1String("\\d|_")))) {
+        if (!(*it).contains(QRegExp(QStringLiteral("\\d|_")))) {
             QString key = (*it).toLower();
             if (map.contains(key))
                 map[key] += 1;
@@ -185,7 +185,7 @@ void addWordsFromFile(WordMap &map, QString filename, QTextCodec *codec)
     QXmlInputSource source(&xmlfile);
     XMLParser parser;
     QXmlSimpleReader reader;
-    reader.setFeature(QLatin1String("http://trolltech.com/xml/features/report-start-end-entity"), true);
+    reader.setFeature(QStringLiteral("http://trolltech.com/xml/features/report-start-end-entity"), true);
     reader.setContentHandler(&parser);
 
     WordMap words;
@@ -230,11 +230,6 @@ void addWordsFromFile(WordMap &map, QString filename, QTextCodec *codec)
     }
 }
 
-}
-#include <kdebug.h>
-namespace WordList
-{
-
 WordMap parseFiles(QStringList files, QTextCodec *codec, QProgressDialog *pdlg)
 {
     int progress = 0;
@@ -315,14 +310,10 @@ WordMap parseKDEDoc(QString language, QProgressDialog *pdlg)
     pdlg->show();
     qApp->processEvents(QEventLoop::AllEvents, 20);
 
-    QStringList files = KGlobal::dirs()->findAllResources("html", language + QLatin1String("/*.docbook"),
-                        KStandardDirs::Recursive |
-                        KStandardDirs::NoDuplicates);
+    QStringList files = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("html/") + language + QStringLiteral("/*.docbook"));
     if ((files.count() == 0) && (language.length() == 5)) {
         language = language.left(2);
-        files = KGlobal::dirs()->findAllResources("html", language + QLatin1String("/*.docbook"),
-                KStandardDirs::Recursive |
-                KStandardDirs::NoDuplicates);
+        files = QStandardPaths::locateAll(QStandardPaths::GenericDataLocation, QStringLiteral("html/") + language + QStringLiteral("/*.docbook"));
     }
 
     return parseFiles(files, QTextCodec::codecForName("UTF-8"), pdlg);
@@ -370,9 +361,8 @@ WordMap parseDir(QString directory, QTextCodec *codec, QProgressDialog *pdlg)
 
     return parseFiles(files, codec, pdlg);
 }
-/***************************************************************************/
 
-#include <QList>
+/***************************************************************************/
 
 /* Structures used for storing *.aff files (part of OpenOffice.org dictionaries)
  */
@@ -397,7 +387,7 @@ void loadAffFile(const QString &filename, AffMap &prefixes, AffMap &suffixes)
         QTextStream stream(&afile);
         while (!stream.atEnd()) {
             QString s = stream.readLine();
-            QStringList fields = s.split(QRegExp(QLatin1String("\\s")));
+            QStringList fields = s.split(QRegExp(QStringLiteral("\\s")));
 
             if (fields.count() == 4) {
                 cross = (fields[2] == QLatin1String("Y"));
@@ -527,7 +517,7 @@ WordMap spellCheck(WordMap map, QString dictionary, QProgressDialog *pdlg)
         AffMap prefixes;
         AffMap suffixes;
         WordMap checkedMap;
-        loadAffFile(dictionary.left(dictionary.length() - 4) + QLatin1String(".aff"), prefixes, suffixes);
+        loadAffFile(dictionary.left(dictionary.length() - 4) + QStringLiteral(".aff"), prefixes, suffixes);
 
         pdlg->reset();
         //pdlg->setAllowCancel (false);
